@@ -505,7 +505,7 @@ xf86UnblockSIGIO (int wasset)
 }
 
 /* This is not the same as the X server one, but it'll do for the tests */
-#if HAVE_XF86OPTIONPTR
+#if GET_ABI_MAJOR(ABI_XINPUT_VERSION) >= 14
 typedef struct _InputOption {
     struct _InputOption *next;
     char *key;
